# Linton

![logo](logo/linton.svg)

Reuben Thomas (rrt@sc3d.org)

Linton is a simple web site builder that converts a tree of Markdown files
and other files, such as images, to a static web site. It is thoroughly
customizable, and comes with a pre-configured web site skeleton that can help get
you started, and serve as an example of its use.

Linton is meant to be simple to use, simple to install and maintain, and its
code should be easy to understand; it is also designed to work for a long
time, with only a few carefully chosen dependencies outside the core Python
system.

Linton is free software, licensed under the GNU General Public License
version 3, or (at your option) any later version. See the file COPYING.

See https://rrthomas.github.io/linton for more information.
